==> libfwbuilder_0.10.4.orig.tar.gz: libfwbuilder-0.10.4.orig/src/fwbuilder/Policy.cc <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 Vadim Kurland

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: Policy.cc,v 1.3 2001/12/19 12:47:01 lord Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#include <fwbuilder/FWObjectDatabase.hh>
#include <fwbuilder/Policy.hh>
#include <fwbuilder/Rule.hh>
#include <fwbuilder/FWOptions.hh>
#include <fwbuilder/XMLTools.hh>
 
using namespace libfwbuilder;

const char *Policy::TYPENAME={"Policy"};

//TODO: move to class or constants. Check if there is similar one in
// some other file - I beleive I already seen this (lord)
static const char*  rels[]={
    "Src",
    "Dst",
    "Srv",
    "Act",
    "When",
    "Opt",
    "Com",
    NULL
};

Policy::Policy()
{
    remStr("name");
    remStr("comment");

    rule_elements=rels;
}

Policy::~Policy() {}

Rule*   Policy::createRule()
{
    Rule      *r;

    r= new PolicyRule();
    r->add( new PolicyRuleOptions() );

    return r;
}

==> libfwbuilder_1.0.2.orig.tar.gz: libfwbuilder-1.0.2/src/fwbuilder/Policy.cc <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: Policy.cc,v 1.8 2002/09/08 19:28:16 vkurland Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include <assert.h>

#include <fwbuilder/FWObjectDatabase.hh>
#include <fwbuilder/Policy.hh>
#include <fwbuilder/Rule.hh>
#include <fwbuilder/FWOptions.hh>
#include <fwbuilder/XMLTools.hh>
 
using namespace libfwbuilder;

const char *Policy::TYPENAME={"Policy"};


Policy::Policy() : RuleSet()
{
    remStr("name");
    remStr("comment");
}

Policy::Policy(const FWObject *root) : RuleSet()
{
    remStr("name");
    remStr("comment");
}

Policy::~Policy() {}

Rule*   Policy::createRule()
{
    FWObjectDatabase* db=dynamic_cast<FWObjectDatabase*>(getRoot());
    assert(db!=NULL);
    return Rule::cast( db->create(PolicyRule::TYPENAME, true) );
}
